# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import json

from aenum import Enum


class UploadType(str, Enum):
    """
    UploadType
    """

    """
    allowed enum values
    """
    RESULT = "result"
    VCF = "vcf"
    CSV = "csv"
    FASTQ = "fastq"
    ARCHIVE_23ANDME = "archive_23andme"

    @classmethod
    def from_json(cls, json_str: str):
        """Create an instance of UploadType from a JSON string"""
        return UploadType(json.loads(json_str))



# coding: utf-8

# flake8: noqa

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# import apis into sdk package
from haplohub.api.accession_api import AccessionApi
from haplohub.api.algorithm_api import AlgorithmApi
from haplohub.api.algorithm_result_api import AlgorithmResultApi
from haplohub.api.algorithm_version_api import AlgorithmVersionApi
from haplohub.api.api_key_api import ApiKeyApi
from haplohub.api.biomarker_api import BiomarkerApi
from haplohub.api.cohort_api import CohortApi
from haplohub.api.environment_api import EnvironmentApi
from haplohub.api.file_api import FileApi
from haplohub.api.log_api import LogApi
from haplohub.api.member_api import MemberApi
from haplohub.api.member_pgs_score_api import MemberPGSScoreApi
from haplohub.api.member_report_api import MemberReportApi
from haplohub.api.report_template_api import ReportTemplateApi
from haplohub.api.sample_api import SampleApi
from haplohub.api.trait_api import TraitApi
from haplohub.api.trait_category_api import TraitCategoryApi
from haplohub.api.upload_api import UploadApi
from haplohub.api.variant_api import VariantApi
from haplohub.api.default_api import DefaultApi

# import ApiClient
from haplohub.api_response import ApiResponse
from haplohub.api_client import ApiClient
from haplohub.configuration import Configuration
from haplohub.exceptions import OpenApiException
from haplohub.exceptions import ApiTypeError
from haplohub.exceptions import ApiValueError
from haplohub.exceptions import ApiKeyError
from haplohub.exceptions import ApiAttributeError
from haplohub.exceptions import ApiException

# import models into sdk package
from haplohub.models.accession_schema import AccessionSchema
from haplohub.models.algorithm_id import AlgorithmId
from haplohub.models.algorithm_result_id import AlgorithmResultId
from haplohub.models.algorithm_result_schema import AlgorithmResultSchema
from haplohub.models.algorithm_schema import AlgorithmSchema
from haplohub.models.algorithm_version_id import AlgorithmVersionId
from haplohub.models.algorithm_version_id1 import AlgorithmVersionId1
from haplohub.models.algorithm_version_schema import AlgorithmVersionSchema
from haplohub.models.api_key_schema import ApiKeySchema
from haplohub.models.auth_schema import AuthSchema
from haplohub.models.biomarker_result_schema import BiomarkerResultSchema
from haplohub.models.cohort_detail_schema import CohortDetailSchema
from haplohub.models.cohort_id import CohortId
from haplohub.models.cohort_id1 import CohortId1
from haplohub.models.cohort_schema import CohortSchema
from haplohub.models.create_algorithm_result_request import CreateAlgorithmResultRequest
from haplohub.models.create_api_key_schema import CreateApiKeySchema
from haplohub.models.create_cohort_request import CreateCohortRequest
from haplohub.models.create_cohort_response import CreateCohortResponse
from haplohub.models.create_environment_request import CreateEnvironmentRequest
from haplohub.models.create_environment_response import CreateEnvironmentResponse
from haplohub.models.create_member_request import CreateMemberRequest
from haplohub.models.create_report_template_request import CreateReportTemplateRequest
from haplohub.models.create_report_template_response import CreateReportTemplateResponse
from haplohub.models.create_sample_request import CreateSampleRequest
from haplohub.models.create_upload_request_request import CreateUploadRequestRequest
from haplohub.models.dir_schema import DirSchema
from haplohub.models.download_link_schema import DownloadLinkSchema
from haplohub.models.environment_id import EnvironmentId
from haplohub.models.environment_schema import EnvironmentSchema
from haplohub.models.error_response import ErrorResponse
from haplohub.models.error_schema import ErrorSchema
from haplohub.models.file_dir_schema import FileDirSchema
from haplohub.models.file_id import FileId
from haplohub.models.file_id1 import FileId1
from haplohub.models.file_info import FileInfo
from haplohub.models.file_schema import FileSchema
from haplohub.models.generic_response import GenericResponse
from haplohub.models.get_cohort_response import GetCohortResponse
from haplohub.models.get_report_template_response import GetReportTemplateResponse
from haplohub.models.get_trait_category_response import GetTraitCategoryResponse
from haplohub.models.get_trait_response import GetTraitResponse
from haplohub.models.get_variant_request import GetVariantRequest
from haplohub.models.hgvs_schema import HgvsSchema
from haplohub.models.id import Id
from haplohub.models.infinity_paginated_response_log_schema import InfinityPaginatedResponseLogSchema
from haplohub.models.list_files_filter import ListFilesFilter
from haplohub.models.list_trait_categories_response import ListTraitCategoriesResponse
from haplohub.models.list_traits_response import ListTraitsResponse
from haplohub.models.log_schema import LogSchema
from haplohub.models.lookup_hgvs_request import LookupHgvsRequest
from haplohub.models.member_id import MemberId
from haplohub.models.member_id1 import MemberId1
from haplohub.models.member_id2 import MemberId2
from haplohub.models.member_schema import MemberSchema
from haplohub.models.order_schema import OrderSchema
from haplohub.models.paginated_response_accession_schema import PaginatedResponseAccessionSchema
from haplohub.models.paginated_response_algorithm_result_schema import PaginatedResponseAlgorithmResultSchema
from haplohub.models.paginated_response_algorithm_schema import PaginatedResponseAlgorithmSchema
from haplohub.models.paginated_response_algorithm_version_schema import PaginatedResponseAlgorithmVersionSchema
from haplohub.models.paginated_response_api_key_schema import PaginatedResponseApiKeySchema
from haplohub.models.paginated_response_cohort_schema import PaginatedResponseCohortSchema
from haplohub.models.paginated_response_environment_schema import PaginatedResponseEnvironmentSchema
from haplohub.models.paginated_response_member_schema import PaginatedResponseMemberSchema
from haplohub.models.paginated_response_report_template_list_schema import PaginatedResponseReportTemplateListSchema
from haplohub.models.paginated_response_sample_schema import PaginatedResponseSampleSchema
from haplohub.models.paginated_response_score_schema import PaginatedResponseScoreSchema
from haplohub.models.report_template_id import ReportTemplateId
from haplohub.models.report_template_id1 import ReportTemplateId1
from haplohub.models.report_template_list_schema import ReportTemplateListSchema
from haplohub.models.report_template_schema import ReportTemplateSchema
from haplohub.models.report_type import ReportType
from haplohub.models.request_schema import RequestSchema
from haplohub.models.response import Response
from haplohub.models.response_schema import ResponseSchema
from haplohub.models.response_status import ResponseStatus
from haplohub.models.result_id import ResultId
from haplohub.models.result_list_response_biomarker_result_schema import ResultListResponseBiomarkerResultSchema
from haplohub.models.result_list_response_hgvs_schema import ResultListResponseHgvsSchema
from haplohub.models.result_list_response_variant_schema import ResultListResponseVariantSchema
from haplohub.models.result_response import ResultResponse
from haplohub.models.result_response_algorithm_result_schema import ResultResponseAlgorithmResultSchema
from haplohub.models.result_response_algorithm_schema import ResultResponseAlgorithmSchema
from haplohub.models.result_response_algorithm_version_schema import ResultResponseAlgorithmVersionSchema
from haplohub.models.result_response_api_key_schema import ResultResponseApiKeySchema
from haplohub.models.result_response_download_link_schema import ResultResponseDownloadLinkSchema
from haplohub.models.result_response_file_dir_schema import ResultResponseFileDirSchema
from haplohub.models.result_response_file_schema import ResultResponseFileSchema
from haplohub.models.result_response_member_schema import ResultResponseMemberSchema
from haplohub.models.result_response_sample_schema import ResultResponseSampleSchema
from haplohub.models.result_response_score_schema import ResultResponseScoreSchema
from haplohub.models.result_response_upload_request_response import ResultResponseUploadRequestResponse
from haplohub.models.result_schema import ResultSchema
from haplohub.models.sample_id import SampleId
from haplohub.models.sample_id1 import SampleId1
from haplohub.models.sample_schema import SampleSchema
from haplohub.models.score_id import ScoreId
from haplohub.models.score_schema import ScoreSchema
from haplohub.models.success_response import SuccessResponse
from haplohub.models.switch_environment_response import SwitchEnvironmentResponse
from haplohub.models.tenant_schema import TenantSchema
from haplohub.models.trait_category_schema import TraitCategorySchema
from haplohub.models.trait_schema import TraitSchema
from haplohub.models.update_cohort_request import UpdateCohortRequest
from haplohub.models.update_cohort_response import UpdateCohortResponse
from haplohub.models.update_member_request import UpdateMemberRequest
from haplohub.models.update_report_template_request import UpdateReportTemplateRequest
from haplohub.models.update_report_template_response import UpdateReportTemplateResponse
from haplohub.models.update_sample_request import UpdateSampleRequest
from haplohub.models.upload_link import UploadLink
from haplohub.models.upload_request_response import UploadRequestResponse
from haplohub.models.upload_type import UploadType
from haplohub.models.variant_range import VariantRange
from haplohub.models.variant_schema import VariantSchema



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.file_schema import FileSchema  # noqa: E501


class TestFileSchema(unittest.TestCase):
    """FileSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileSchema:
        """Test FileSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `FileSchema`
        """
        model = FileSchema()  # noqa: E501
        if include_optional:
            return FileSchema(
                sample = haplohub.models.sample_schema.SampleSchema(
                    id = 56, 
                    sample_id = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                id = 56,
                filename = '',
                file_size = 56,
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return FileSchema(
                filename = '',
                file_size = 56,
        )
        """

    def testFileSchema(self):
        """Test FileSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.result_id import ResultId  # noqa: E501


class TestResultId(unittest.TestCase):
    """ResultId unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultId:
        """Test ResultId
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResultId`
        """
        model = ResultId()  # noqa: E501
        if include_optional:
            return ResultId(
            )
        else:
            return ResultId(
        )
        """

    def testResultId(self):
        """Test ResultId"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.log_api import LogApi  # noqa: E501


class TestLogApi(unittest.TestCase):
    """LogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LogApi()

    def tearDown(self) -> None:
        pass

    def test_list_logs(self) -> None:
        """Test case for list_logs

        List logs  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.workflow_api import WorkflowApi  # noqa: E501


class TestWorkflowApi(unittest.TestCase):
    """WorkflowApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkflowApi()

    def tearDown(self) -> None:
        pass

    def test_get_workflow_run(self) -> None:
        """Test case for get_workflow_run

        Get workflow run  # noqa: E501
        """
        pass

    def test_list_workflow_runs(self) -> None:
        """Test case for list_workflow_runs

        List workflow runs  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.result_response_upload_request_response import ResultResponseUploadRequestResponse  # noqa: E501


class TestResultResponseUploadRequestResponse(unittest.TestCase):
    """ResultResponseUploadRequestResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultResponseUploadRequestResponse:
        """Test ResultResponseUploadRequestResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResultResponseUploadRequestResponse`
        """
        model = ResultResponseUploadRequestResponse()  # noqa: E501
        if include_optional:
            return ResultResponseUploadRequestResponse(
                status = 'success',
                result = haplohub.models.upload_request_response.UploadRequestResponse(
                    upload_request_id = '', 
                    upload_links = [
                        haplohub.models.upload_link.UploadLink(
                            original_file_path = '', 
                            file_path = '', 
                            signed_url = '', )
                        ], )
            )
        else:
            return ResultResponseUploadRequestResponse(
                result = haplohub.models.upload_request_response.UploadRequestResponse(
                    upload_request_id = '', 
                    upload_links = [
                        haplohub.models.upload_link.UploadLink(
                            original_file_path = '', 
                            file_path = '', 
                            signed_url = '', )
                        ], ),
        )
        """

    def testResultResponseUploadRequestResponse(self):
        """Test ResultResponseUploadRequestResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.report_template_api import ReportTemplateApi  # noqa: E501


class TestReportTemplateApi(unittest.TestCase):
    """ReportTemplateApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportTemplateApi()

    def tearDown(self) -> None:
        pass

    def test_create_report_template(self) -> None:
        """Test case for create_report_template

        Create report template  # noqa: E501
        """
        pass

    def test_delete_report_template(self) -> None:
        """Test case for delete_report_template

        Delete report template  # noqa: E501
        """
        pass

    def test_get_report_template(self) -> None:
        """Test case for get_report_template

        Get report template  # noqa: E501
        """
        pass

    def test_list_report_templates(self) -> None:
        """Test case for list_report_templates

        List report templates  # noqa: E501
        """
        pass

    def test_preview_report_template(self) -> None:
        """Test case for preview_report_template

        Preview report template  # noqa: E501
        """
        pass

    def test_update_report_template(self) -> None:
        """Test case for update_report_template

        Update report template  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime

from pydantic import BaseModel, Field

from haplohub.models.auth_schema import AuthSchema
from haplohub.models.request_schema import RequestSchema
from haplohub.models.response_schema import ResponseSchema
from haplohub.models.tenant_schema import TenantSchema


class LogSchema(BaseModel):
    """
    LogSchema
    """

    timestamp: datetime = Field(...)
    tenant: TenantSchema = Field(...)
    auth: AuthSchema = Field(...)
    request: RequestSchema = Field(...)
    response: ResponseSchema = Field(...)
    __properties = ["timestamp", "tenant", "auth", "request", "response"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LogSchema:
        """Create an instance of LogSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of tenant
        if self.tenant:
            _dict["tenant"] = self.tenant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict["auth"] = self.auth.to_dict()
        # override the default output from pydantic by calling `to_dict()` of request
        if self.request:
            _dict["request"] = self.request.to_dict()
        # override the default output from pydantic by calling `to_dict()` of response
        if self.response:
            _dict["response"] = self.response.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LogSchema:
        """Create an instance of LogSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LogSchema.parse_obj(obj)

        _obj = LogSchema.parse_obj(
            {
                "timestamp": obj.get("timestamp"),
                "tenant": TenantSchema.from_dict(obj.get("tenant")) if obj.get("tenant") is not None else None,
                "auth": AuthSchema.from_dict(obj.get("auth")) if obj.get("auth") is not None else None,
                "request": RequestSchema.from_dict(obj.get("request")) if obj.get("request") is not None else None,
                "response": ResponseSchema.from_dict(obj.get("response")) if obj.get("response") is not None else None,
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

try:
    from ._version import __version__
except ImportError:
    __version__ = "0.0.0+unknown"

# import models into model package
from haplohub.models.accession_schema import AccessionSchema
from haplohub.models.algorithm_id import AlgorithmId
from haplohub.models.algorithm_result_id import AlgorithmResultId
from haplohub.models.algorithm_result_schema import AlgorithmResultSchema
from haplohub.models.algorithm_schema import AlgorithmSchema
from haplohub.models.algorithm_version_id import AlgorithmVersionId
from haplohub.models.algorithm_version_id1 import AlgorithmVersionId1
from haplohub.models.algorithm_version_schema import AlgorithmVersionSchema
from haplohub.models.api_key_schema import ApiKeySchema
from haplohub.models.auth_schema import AuthSchema
from haplohub.models.biomarker_result_schema import BiomarkerResultSchema
from haplohub.models.cohort_detail_schema import CohortDetailSchema
from haplohub.models.cohort_id import CohortId
from haplohub.models.cohort_id1 import CohortId1
from haplohub.models.cohort_schema import CohortSchema
from haplohub.models.create_algorithm_result_request import CreateAlgorithmResultRequest
from haplohub.models.create_api_key_schema import CreateApiKeySchema
from haplohub.models.create_cohort_request import CreateCohortRequest
from haplohub.models.create_cohort_response import CreateCohortResponse
from haplohub.models.create_environment_request import CreateEnvironmentRequest
from haplohub.models.create_environment_response import CreateEnvironmentResponse
from haplohub.models.create_member_request import CreateMemberRequest
from haplohub.models.create_report_template_request import CreateReportTemplateRequest
from haplohub.models.create_report_template_response import CreateReportTemplateResponse
from haplohub.models.create_sample_request import CreateSampleRequest
from haplohub.models.create_upload_request_request import CreateUploadRequestRequest
from haplohub.models.dir_schema import DirSchema
from haplohub.models.download_link_schema import DownloadLinkSchema
from haplohub.models.environment_id import EnvironmentId
from haplohub.models.environment_schema import EnvironmentSchema
from haplohub.models.error_response import ErrorResponse
from haplohub.models.error_schema import ErrorSchema
from haplohub.models.file_dir_schema import FileDirSchema
from haplohub.models.file_id import FileId
from haplohub.models.file_id1 import FileId1
from haplohub.models.file_info import FileInfo
from haplohub.models.file_schema import FileSchema
from haplohub.models.generic_response import GenericResponse
from haplohub.models.get_cohort_response import GetCohortResponse
from haplohub.models.get_report_template_response import GetReportTemplateResponse
from haplohub.models.get_trait_category_response import GetTraitCategoryResponse
from haplohub.models.get_trait_response import GetTraitResponse
from haplohub.models.get_variant_request import GetVariantRequest
from haplohub.models.hgvs_schema import HgvsSchema
from haplohub.models.id import Id
from haplohub.models.infinity_paginated_response_log_schema import InfinityPaginatedResponseLogSchema
from haplohub.models.list_files_filter import ListFilesFilter
from haplohub.models.list_trait_categories_response import ListTraitCategoriesResponse
from haplohub.models.list_traits_response import ListTraitsResponse
from haplohub.models.log_schema import LogSchema
from haplohub.models.lookup_hgvs_request import LookupHgvsRequest
from haplohub.models.member_id import MemberId
from haplohub.models.member_id1 import MemberId1
from haplohub.models.member_id2 import MemberId2
from haplohub.models.member_schema import MemberSchema
from haplohub.models.order_schema import OrderSchema
from haplohub.models.paginated_response_accession_schema import PaginatedResponseAccessionSchema
from haplohub.models.paginated_response_algorithm_result_schema import PaginatedResponseAlgorithmResultSchema
from haplohub.models.paginated_response_algorithm_schema import PaginatedResponseAlgorithmSchema
from haplohub.models.paginated_response_algorithm_version_schema import PaginatedResponseAlgorithmVersionSchema
from haplohub.models.paginated_response_api_key_schema import PaginatedResponseApiKeySchema
from haplohub.models.paginated_response_cohort_schema import PaginatedResponseCohortSchema
from haplohub.models.paginated_response_environment_schema import PaginatedResponseEnvironmentSchema
from haplohub.models.paginated_response_member_schema import PaginatedResponseMemberSchema
from haplohub.models.paginated_response_report_template_list_schema import PaginatedResponseReportTemplateListSchema
from haplohub.models.paginated_response_sample_schema import PaginatedResponseSampleSchema
from haplohub.models.paginated_response_score_schema import PaginatedResponseScoreSchema
from haplohub.models.report_template_id import ReportTemplateId
from haplohub.models.report_template_id1 import ReportTemplateId1
from haplohub.models.report_template_list_schema import ReportTemplateListSchema
from haplohub.models.report_template_schema import ReportTemplateSchema
from haplohub.models.report_type import ReportType
from haplohub.models.request_schema import RequestSchema
from haplohub.models.response import Response
from haplohub.models.response_schema import ResponseSchema
from haplohub.models.response_status import ResponseStatus
from haplohub.models.result_id import ResultId
from haplohub.models.result_list_response_biomarker_result_schema import ResultListResponseBiomarkerResultSchema
from haplohub.models.result_list_response_hgvs_schema import ResultListResponseHgvsSchema
from haplohub.models.result_list_response_variant_schema import ResultListResponseVariantSchema
from haplohub.models.result_response import ResultResponse
from haplohub.models.result_response_algorithm_result_schema import ResultResponseAlgorithmResultSchema
from haplohub.models.result_response_algorithm_schema import ResultResponseAlgorithmSchema
from haplohub.models.result_response_algorithm_version_schema import ResultResponseAlgorithmVersionSchema
from haplohub.models.result_response_api_key_schema import ResultResponseApiKeySchema
from haplohub.models.result_response_download_link_schema import ResultResponseDownloadLinkSchema
from haplohub.models.result_response_file_dir_schema import ResultResponseFileDirSchema
from haplohub.models.result_response_file_schema import ResultResponseFileSchema
from haplohub.models.result_response_member_schema import ResultResponseMemberSchema
from haplohub.models.result_response_sample_schema import ResultResponseSampleSchema
from haplohub.models.result_response_score_schema import ResultResponseScoreSchema
from haplohub.models.result_response_upload_request_response import ResultResponseUploadRequestResponse
from haplohub.models.result_schema import ResultSchema
from haplohub.models.sample_id import SampleId
from haplohub.models.sample_id1 import SampleId1
from haplohub.models.sample_schema import SampleSchema
from haplohub.models.score_id import ScoreId
from haplohub.models.score_schema import ScoreSchema
from haplohub.models.success_response import SuccessResponse
from haplohub.models.switch_environment_response import SwitchEnvironmentResponse
from haplohub.models.tenant_schema import TenantSchema
from haplohub.models.trait_category_schema import TraitCategorySchema
from haplohub.models.trait_schema import TraitSchema
from haplohub.models.update_cohort_request import UpdateCohortRequest
from haplohub.models.update_cohort_response import UpdateCohortResponse
from haplohub.models.update_member_request import UpdateMemberRequest
from haplohub.models.update_report_template_request import UpdateReportTemplateRequest
from haplohub.models.update_report_template_response import UpdateReportTemplateResponse
from haplohub.models.update_sample_request import UpdateSampleRequest
from haplohub.models.upload_link import UploadLink
from haplohub.models.upload_request_response import UploadRequestResponse
from haplohub.models.upload_type import UploadType
from haplohub.models.variant_range import VariantRange
from haplohub.models.variant_schema import VariantSchema



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.accession_schema import AccessionSchema  # noqa: E501


class TestAccessionSchema(unittest.TestCase):
    """AccessionSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessionSchema:
        """Test AccessionSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccessionSchema`
        """
        model = AccessionSchema()  # noqa: E501
        if include_optional:
            return AccessionSchema(
                chromosome = '',
                accession = '',
                length = 56,
                build = '',
                build_version = ''
            )
        else:
            return AccessionSchema(
                chromosome = '',
                accession = '',
                length = 56,
                build = '',
                build_version = '',
        )
        """

    def testAccessionSchema(self):
        """Test AccessionSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.variant_schema import VariantSchema  # noqa: E501


class TestVariantSchema(unittest.TestCase):
    """VariantSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VariantSchema:
        """Test VariantSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `VariantSchema`
        """
        model = VariantSchema()  # noqa: E501
        if include_optional:
            return VariantSchema(
                accession = '',
                position = 56,
                id = '',
                reference = '',
                alternate = [
                    ''
                    ],
                quality = 1.337
            )
        else:
            return VariantSchema(
                accession = '',
                position = 56,
                id = '',
                reference = '',
                alternate = [
                    ''
                    ],
                quality = 1.337,
        )
        """

    def testVariantSchema(self):
        """Test VariantSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.file_api import FileApi  # noqa: E501


class TestFileApi(unittest.TestCase):
    """FileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FileApi()

    def tearDown(self) -> None:
        pass

    def test_delete_file(self) -> None:
        """Test case for delete_file

        Delete file  # noqa: E501
        """
        pass

    def test_download_link(self) -> None:
        """Test case for download_link

        Get download link  # noqa: E501
        """
        pass

    def test_finish_uploading(self) -> None:
        """Test case for finish_uploading

        Finish uploading  # noqa: E501
        """
        pass

    def test_get_file(self) -> None:
        """Test case for get_file

        Get file  # noqa: E501
        """
        pass

    def test_list_files(self) -> None:
        """Test case for list_files

        List files  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.algorithm_result_schema import AlgorithmResultSchema  # noqa: E501


class TestAlgorithmResultSchema(unittest.TestCase):
    """AlgorithmResultSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlgorithmResultSchema:
        """Test AlgorithmResultSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AlgorithmResultSchema`
        """
        model = AlgorithmResultSchema()  # noqa: E501
        if include_optional:
            return AlgorithmResultSchema(
                id = '',
                algorithm_version_id = '',
                cohort_id = '',
                input = haplohub.models.input.Input(),
                output = haplohub.models.output.Output(),
                status = 'Pending',
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                time_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return AlgorithmResultSchema(
                id = '',
                algorithm_version_id = '',
                cohort_id = '',
                input = haplohub.models.input.Input(),
                output = haplohub.models.output.Output(),
                status = 'Pending',
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                time_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testAlgorithmResultSchema(self):
        """Test AlgorithmResultSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.infinity_paginated_response_log_schema import InfinityPaginatedResponseLogSchema  # noqa: E501


class TestInfinityPaginatedResponseLogSchema(unittest.TestCase):
    """InfinityPaginatedResponseLogSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InfinityPaginatedResponseLogSchema:
        """Test InfinityPaginatedResponseLogSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `InfinityPaginatedResponseLogSchema`
        """
        model = InfinityPaginatedResponseLogSchema()  # noqa: E501
        if include_optional:
            return InfinityPaginatedResponseLogSchema(
                status = 'success',
                items = [
                    haplohub.models.log_schema.LogSchema(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        tenant = haplohub.models.tenant_schema.TenantSchema(
                            org_id = 56, 
                            org_external_id = '', ), 
                        auth = haplohub.models.auth_schema.AuthSchema(
                            ip = '', 
                            id = '', 
                            sub = '', ), 
                        request = haplohub.models.request_schema.RequestSchema(
                            method = '', 
                            path = '', 
                            env_id = 56, ), 
                        response = haplohub.models.response_schema.ResponseSchema(
                            status_code = 56, ), )
                    ],
                has_more = True,
                cursor = ''
            )
        else:
            return InfinityPaginatedResponseLogSchema(
                items = [
                    haplohub.models.log_schema.LogSchema(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        tenant = haplohub.models.tenant_schema.TenantSchema(
                            org_id = 56, 
                            org_external_id = '', ), 
                        auth = haplohub.models.auth_schema.AuthSchema(
                            ip = '', 
                            id = '', 
                            sub = '', ), 
                        request = haplohub.models.request_schema.RequestSchema(
                            method = '', 
                            path = '', 
                            env_id = 56, ), 
                        response = haplohub.models.response_schema.ResponseSchema(
                            status_code = 56, ), )
                    ],
                has_more = True,
        )
        """

    def testInfinityPaginatedResponseLogSchema(self):
        """Test InfinityPaginatedResponseLogSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field, StrictInt, constr


class UploadRequstSchema(BaseModel):
    """
    UploadRequstSchema
    """

    id: Optional[StrictInt] = None
    filename: constr(strict=True, max_length=255) = Field(...)
    file_size: StrictInt = Field(...)
    md5_checksum: constr(strict=True, max_length=32) = Field(...)
    created: Optional[datetime] = None
    __properties = ["id", "filename", "file_size", "md5_checksum", "created"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UploadRequstSchema:
        """Create an instance of UploadRequstSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict["id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UploadRequstSchema:
        """Create an instance of UploadRequstSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UploadRequstSchema.parse_obj(obj)

        _obj = UploadRequstSchema.parse_obj(
            {
                "id": obj.get("id"),
                "filename": obj.get("filename"),
                "file_size": obj.get("file_size"),
                "md5_checksum": obj.get("md5_checksum"),
                "created": obj.get("created"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.member_api import MemberApi  # noqa: E501


class TestMemberApi(unittest.TestCase):
    """MemberApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MemberApi()

    def tearDown(self) -> None:
        pass

    def test_delete_member(self) -> None:
        """Test case for delete_member

        Delete member  # noqa: E501
        """
        pass

    def test_get_member(self) -> None:
        """Test case for get_member

        Get member  # noqa: E501
        """
        pass

    def test_list_members(self) -> None:
        """Test case for list_members

        List members  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401

from pydantic import BaseModel, Field, StrictStr

from haplohub.models.upload_requst_schema import UploadRequstSchema


class UploadLinkSchema(BaseModel):
    """
    UploadLinkSchema
    """

    upload_link: StrictStr = Field(...)
    upload_request: UploadRequstSchema = Field(...)
    __properties = ["upload_link", "upload_request"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UploadLinkSchema:
        """Create an instance of UploadLinkSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of upload_request
        if self.upload_request:
            _dict["upload_request"] = self.upload_request.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UploadLinkSchema:
        """Create an instance of UploadLinkSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UploadLinkSchema.parse_obj(obj)

        _obj = UploadLinkSchema.parse_obj(
            {
                "upload_link": obj.get("upload_link"),
                "upload_request": UploadRequstSchema.from_dict(obj.get("upload_request"))
                if obj.get("upload_request") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest


class TestPredictionStatus(unittest.TestCase):
    """PredictionStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPredictionStatus(self):
        """Test PredictionStatus"""
        # inst = PredictionStatus()


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.paginated_response_sample_file_schema import PaginatedResponseSampleFileSchema  # noqa: E501


class TestPaginatedResponseSampleFileSchema(unittest.TestCase):
    """PaginatedResponseSampleFileSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSampleFileSchema:
        """Test PaginatedResponseSampleFileSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PaginatedResponseSampleFileSchema`
        """
        model = PaginatedResponseSampleFileSchema()  # noqa: E501
        if include_optional:
            return PaginatedResponseSampleFileSchema(
                status = 'success',
                total_count = 56,
                items = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedResponseSampleFileSchema(
                total_count = 56,
                items = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testPaginatedResponseSampleFileSchema(self):
        """Test PaginatedResponseSampleFileSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.get_cohort_response import GetCohortResponse  # noqa: E501


class TestGetCohortResponse(unittest.TestCase):
    """GetCohortResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetCohortResponse:
        """Test GetCohortResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetCohortResponse`
        """
        model = GetCohortResponse()  # noqa: E501
        if include_optional:
            return GetCohortResponse(
                status = 'success',
                result = haplohub.models.cohort_detail_schema.CohortDetailSchema(
                    id = 56, 
                    name = '', 
                    slug = '', 
                    description = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    sample_files = [
                        haplohub.models.sample_file_schema.SampleFileSchema(
                            id = 56, 
                            filename = '', 
                            file_size = 56, 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], )
            )
        else:
            return GetCohortResponse(
                result = haplohub.models.cohort_detail_schema.CohortDetailSchema(
                    id = 56, 
                    name = '', 
                    slug = '', 
                    description = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    sample_files = [
                        haplohub.models.sample_file_schema.SampleFileSchema(
                            id = 56, 
                            filename = '', 
                            file_size = 56, 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], ),
        )
        """

    def testGetCohortResponse(self):
        """Test GetCohortResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.biomarker_result_schema import BiomarkerResultSchema  # noqa: E501


class TestBiomarkerResultSchema(unittest.TestCase):
    """BiomarkerResultSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BiomarkerResultSchema:
        """Test BiomarkerResultSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BiomarkerResultSchema`
        """
        model = BiomarkerResultSchema()  # noqa: E501
        if include_optional:
            return BiomarkerResultSchema(
                order = haplohub.models.order_schema.OrderSchema(
                    id = 56, 
                    age = 56, 
                    dob = '', 
                    clia_number = '', 
                    patient = '', 
                    provider = '', 
                    laboratory = '', 
                    date_reported = '', 
                    date_collected = '', 
                    specimen_number = '', 
                    date_received = '', 
                    status = '', 
                    interpretation = '', ),
                results = [
                    haplohub.models.result_schema.ResultSchema(
                        name = '', 
                        slug = '', 
                        value = 1.337, 
                        result = '', 
                        type = '', 
                        unit = '', 
                        timestamp = '', 
                        notes = '', 
                        min_range_value = 1.337, 
                        max_range_value = 1.337, 
                        is_above_max_range = True, 
                        is_below_min_range = True, 
                        interpretation = '', 
                        loinc = '', 
                        loinc_slug = '', 
                        provider_id = '', )
                    ]
            )
        else:
            return BiomarkerResultSchema(
                order = haplohub.models.order_schema.OrderSchema(
                    id = 56, 
                    age = 56, 
                    dob = '', 
                    clia_number = '', 
                    patient = '', 
                    provider = '', 
                    laboratory = '', 
                    date_reported = '', 
                    date_collected = '', 
                    specimen_number = '', 
                    date_received = '', 
                    status = '', 
                    interpretation = '', ),
                results = [
                    haplohub.models.result_schema.ResultSchema(
                        name = '', 
                        slug = '', 
                        value = 1.337, 
                        result = '', 
                        type = '', 
                        unit = '', 
                        timestamp = '', 
                        notes = '', 
                        min_range_value = 1.337, 
                        max_range_value = 1.337, 
                        is_above_max_range = True, 
                        is_below_min_range = True, 
                        interpretation = '', 
                        loinc = '', 
                        loinc_slug = '', 
                        provider_id = '', )
                    ],
        )
        """

    def testBiomarkerResultSchema(self):
        """Test BiomarkerResultSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field, StrictInt, constr

from haplohub.models.user_schema import UserSchema


class WorkflowRunSchema(BaseModel):
    """
    WorkflowRunSchema
    """

    triggered_by: Optional[UserSchema] = None
    id: Optional[StrictInt] = None
    workflow_id: constr(strict=True, max_length=255) = Field(...)
    workflow_type: constr(strict=True, max_length=255) = Field(...)
    started_at: datetime = Field(...)
    __properties = ["triggered_by", "id", "workflow_id", "workflow_type", "started_at"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WorkflowRunSchema:
        """Create an instance of WorkflowRunSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of triggered_by
        if self.triggered_by:
            _dict["triggered_by"] = self.triggered_by.to_dict()
        # set to None if triggered_by (nullable) is None
        # and __fields_set__ contains the field
        if self.triggered_by is None and "triggered_by" in self.__fields_set__:
            _dict["triggered_by"] = None

        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict["id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WorkflowRunSchema:
        """Create an instance of WorkflowRunSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WorkflowRunSchema.parse_obj(obj)

        _obj = WorkflowRunSchema.parse_obj(
            {
                "triggered_by": UserSchema.from_dict(obj.get("triggered_by")) if obj.get("triggered_by") is not None else None,
                "id": obj.get("id"),
                "workflow_id": obj.get("workflow_id"),
                "workflow_type": obj.get("workflow_type"),
                "started_at": obj.get("started_at"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.result_list_response_variant_schema import ResultListResponseVariantSchema  # noqa: E501


class TestResultListResponseVariantSchema(unittest.TestCase):
    """ResultListResponseVariantSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultListResponseVariantSchema:
        """Test ResultListResponseVariantSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResultListResponseVariantSchema`
        """
        model = ResultListResponseVariantSchema()  # noqa: E501
        if include_optional:
            return ResultListResponseVariantSchema(
                status = 'success',
                items = [
                    haplohub.models.variant_schema.VariantSchema(
                        accession = '', 
                        position = 56, 
                        id = '', 
                        reference = '', 
                        alternate = [
                            ''
                            ], 
                        quality = 1.337, )
                    ]
            )
        else:
            return ResultListResponseVariantSchema(
                items = [
                    haplohub.models.variant_schema.VariantSchema(
                        accession = '', 
                        position = 56, 
                        id = '', 
                        reference = '', 
                        alternate = [
                            ''
                            ], 
                        quality = 1.337, )
                    ],
        )
        """

    def testResultListResponseVariantSchema(self):
        """Test ResultListResponseVariantSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401

from pydantic import BaseModel, Field, StrictStr


class ErrorSchema(BaseModel):
    """
    ErrorSchema
    """

    code: StrictStr = Field(...)
    message: StrictStr = Field(...)
    __properties = ["code", "message"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ErrorSchema:
        """Create an instance of ErrorSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ErrorSchema:
        """Create an instance of ErrorSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ErrorSchema.parse_obj(obj)

        _obj = ErrorSchema.parse_obj({"code": obj.get("code"), "message": obj.get("message")})
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.hgvs_dosage_schema import HgvsDosageSchema  # noqa: E501


class TestHgvsDosageSchema(unittest.TestCase):
    """HgvsDosageSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HgvsDosageSchema:
        """Test HgvsDosageSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `HgvsDosageSchema`
        """
        model = HgvsDosageSchema()  # noqa: E501
        if include_optional:
            return HgvsDosageSchema(
                sample_id = '',
                description = '',
                dosage = 56
            )
        else:
            return HgvsDosageSchema(
                sample_id = '',
                description = '',
                dosage = 56,
        )
        """

    def testHgvsDosageSchema(self):
        """Test HgvsDosageSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional, Union

from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

from haplohub.models.most_similar_population import MostSimilarPopulation


class MemberPgsScoreSchema(BaseModel):
    """
    MemberPgsScoreSchema
    """

    id: StrictStr = Field(...)
    cohort_id: StrictStr = Field(...)
    member_id: StrictStr = Field(...)
    trait_id: StrictStr = Field(...)
    adjusted_z_score: Union[StrictFloat, StrictInt] = Field(...)
    percentile: Union[StrictFloat, StrictInt] = Field(...)
    relative_risk: Optional[Union[StrictFloat, StrictInt]] = None
    most_similar_population: MostSimilarPopulation = Field(...)
    source_algorithm_result_id: StrictStr = Field(...)
    time_created: datetime = Field(...)
    __properties = [
        "id",
        "cohort_id",
        "member_id",
        "trait_id",
        "adjusted_z_score",
        "percentile",
        "relative_risk",
        "most_similar_population",
        "source_algorithm_result_id",
        "time_created",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MemberPgsScoreSchema:
        """Create an instance of MemberPgsScoreSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if relative_risk (nullable) is None
        # and __fields_set__ contains the field
        if self.relative_risk is None and "relative_risk" in self.__fields_set__:
            _dict["relative_risk"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MemberPgsScoreSchema:
        """Create an instance of MemberPgsScoreSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MemberPgsScoreSchema.parse_obj(obj)

        _obj = MemberPgsScoreSchema.parse_obj(
            {
                "id": obj.get("id"),
                "cohort_id": obj.get("cohort_id"),
                "member_id": obj.get("member_id"),
                "trait_id": obj.get("trait_id"),
                "adjusted_z_score": obj.get("adjusted_z_score"),
                "percentile": obj.get("percentile"),
                "relative_risk": obj.get("relative_risk"),
                "most_similar_population": obj.get("most_similar_population"),
                "source_algorithm_result_id": obj.get("source_algorithm_result_id"),
                "time_created": obj.get("time_created"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.accession_api import AccessionApi  # noqa: E501


class TestAccessionApi(unittest.TestCase):
    """AccessionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccessionApi()

    def tearDown(self) -> None:
        pass

    def test_list_accession(self) -> None:
        """Test case for list_accession

        List Accessions  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.member_schema import MemberSchema  # noqa: E501


class TestMemberSchema(unittest.TestCase):
    """MemberSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MemberSchema:
        """Test MemberSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `MemberSchema`
        """
        model = MemberSchema()  # noqa: E501
        if include_optional:
            return MemberSchema(
                id = 56,
                patient_id = '',
                first_name = '',
                last_name = '',
                gender = '',
                birth_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return MemberSchema(
        )
        """

    def testMemberSchema(self):
        """Test MemberSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest


class TestMostSimilarPopulation(unittest.TestCase):
    """MostSimilarPopulation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMostSimilarPopulation(self):
        """Test MostSimilarPopulation"""
        # inst = MostSimilarPopulation()


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.get_hgvs_response import GetHgvsResponse  # noqa: E501


class TestGetHgvsResponse(unittest.TestCase):
    """GetHgvsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetHgvsResponse:
        """Test GetHgvsResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetHgvsResponse`
        """
        model = GetHgvsResponse()  # noqa: E501
        if include_optional:
            return GetHgvsResponse(
                status = 'success',
                result = haplohub.models.hgvs_dosage_schema.HgvsDosageSchema(
                    sample_id = '', 
                    description = '', 
                    dosage = 56, )
            )
        else:
            return GetHgvsResponse(
                result = haplohub.models.hgvs_dosage_schema.HgvsDosageSchema(
                    sample_id = '', 
                    description = '', 
                    dosage = 56, ),
        )
        """

    def testGetHgvsResponse(self):
        """Test GetHgvsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field

from haplohub.models.push_credentials import PushCredentials
from haplohub.models.response_status import ResponseStatus


class ResultResponsePushCredentials(BaseModel):
    """
    ResultResponsePushCredentials
    """

    status: Optional[ResponseStatus] = None
    result: PushCredentials = Field(...)
    __properties = ["status", "result"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResultResponsePushCredentials:
        """Create an instance of ResultResponsePushCredentials from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict["result"] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResultResponsePushCredentials:
        """Create an instance of ResultResponsePushCredentials from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResultResponsePushCredentials.parse_obj(obj)

        _obj = ResultResponsePushCredentials.parse_obj(
            {
                "status": obj.get("status"),
                "result": PushCredentials.from_dict(obj.get("result")) if obj.get("result") is not None else None,
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import date, datetime
from typing import Optional

from pydantic import BaseModel, Field, StrictInt, StrictStr


class OrderSchema(BaseModel):
    """
    OrderSchema
    """

    id: StrictStr = Field(...)
    age: Optional[StrictInt] = None
    dob: Optional[date] = None
    clia_number: Optional[StrictStr] = None
    patient: Optional[StrictStr] = None
    provider: Optional[StrictStr] = None
    laboratory: Optional[StrictStr] = None
    date_reported: Optional[datetime] = None
    date_collected: Optional[datetime] = None
    specimen_number: Optional[StrictStr] = None
    date_received: Optional[datetime] = None
    status: Optional[StrictStr] = None
    interpretation: Optional[StrictStr] = None
    __properties = [
        "id",
        "age",
        "dob",
        "clia_number",
        "patient",
        "provider",
        "laboratory",
        "date_reported",
        "date_collected",
        "specimen_number",
        "date_received",
        "status",
        "interpretation",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrderSchema:
        """Create an instance of OrderSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if age (nullable) is None
        # and __fields_set__ contains the field
        if self.age is None and "age" in self.__fields_set__:
            _dict["age"] = None

        # set to None if dob (nullable) is None
        # and __fields_set__ contains the field
        if self.dob is None and "dob" in self.__fields_set__:
            _dict["dob"] = None

        # set to None if clia_number (nullable) is None
        # and __fields_set__ contains the field
        if self.clia_number is None and "clia_number" in self.__fields_set__:
            _dict["clia_number"] = None

        # set to None if patient (nullable) is None
        # and __fields_set__ contains the field
        if self.patient is None and "patient" in self.__fields_set__:
            _dict["patient"] = None

        # set to None if provider (nullable) is None
        # and __fields_set__ contains the field
        if self.provider is None and "provider" in self.__fields_set__:
            _dict["provider"] = None

        # set to None if laboratory (nullable) is None
        # and __fields_set__ contains the field
        if self.laboratory is None and "laboratory" in self.__fields_set__:
            _dict["laboratory"] = None

        # set to None if date_reported (nullable) is None
        # and __fields_set__ contains the field
        if self.date_reported is None and "date_reported" in self.__fields_set__:
            _dict["date_reported"] = None

        # set to None if date_collected (nullable) is None
        # and __fields_set__ contains the field
        if self.date_collected is None and "date_collected" in self.__fields_set__:
            _dict["date_collected"] = None

        # set to None if specimen_number (nullable) is None
        # and __fields_set__ contains the field
        if self.specimen_number is None and "specimen_number" in self.__fields_set__:
            _dict["specimen_number"] = None

        # set to None if date_received (nullable) is None
        # and __fields_set__ contains the field
        if self.date_received is None and "date_received" in self.__fields_set__:
            _dict["date_received"] = None

        # set to None if status (nullable) is None
        # and __fields_set__ contains the field
        if self.status is None and "status" in self.__fields_set__:
            _dict["status"] = None

        # set to None if interpretation (nullable) is None
        # and __fields_set__ contains the field
        if self.interpretation is None and "interpretation" in self.__fields_set__:
            _dict["interpretation"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrderSchema:
        """Create an instance of OrderSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrderSchema.parse_obj(obj)

        _obj = OrderSchema.parse_obj(
            {
                "id": obj.get("id"),
                "age": obj.get("age"),
                "dob": obj.get("dob"),
                "clia_number": obj.get("clia_number"),
                "patient": obj.get("patient"),
                "provider": obj.get("provider"),
                "laboratory": obj.get("laboratory"),
                "date_reported": obj.get("date_reported"),
                "date_collected": obj.get("date_collected"),
                "specimen_number": obj.get("specimen_number"),
                "date_received": obj.get("date_received"),
                "status": obj.get("status"),
                "interpretation": obj.get("interpretation"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.result_list_response_biomarker_result_schema import ResultListResponseBiomarkerResultSchema  # noqa: E501


class TestResultListResponseBiomarkerResultSchema(unittest.TestCase):
    """ResultListResponseBiomarkerResultSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultListResponseBiomarkerResultSchema:
        """Test ResultListResponseBiomarkerResultSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResultListResponseBiomarkerResultSchema`
        """
        model = ResultListResponseBiomarkerResultSchema()  # noqa: E501
        if include_optional:
            return ResultListResponseBiomarkerResultSchema(
                status = 'success',
                items = [
                    haplohub.models.biomarker_result_schema.BiomarkerResultSchema(
                        order = haplohub.models.order_schema.OrderSchema(
                            id = 56, 
                            age = 56, 
                            dob = '', 
                            clia_number = '', 
                            patient = '', 
                            provider = '', 
                            laboratory = '', 
                            date_reported = '', 
                            date_collected = '', 
                            specimen_number = '', 
                            date_received = '', 
                            status = '', 
                            interpretation = '', ), 
                        results = [
                            haplohub.models.result_schema.ResultSchema(
                                name = '', 
                                slug = '', 
                                value = 1.337, 
                                result = '', 
                                type = '', 
                                unit = '', 
                                timestamp = '', 
                                notes = '', 
                                min_range_value = 1.337, 
                                max_range_value = 1.337, 
                                is_above_max_range = True, 
                                is_below_min_range = True, 
                                interpretation = '', 
                                loinc = '', 
                                loinc_slug = '', 
                                provider_id = '', )
                            ], )
                    ]
            )
        else:
            return ResultListResponseBiomarkerResultSchema(
                items = [
                    haplohub.models.biomarker_result_schema.BiomarkerResultSchema(
                        order = haplohub.models.order_schema.OrderSchema(
                            id = 56, 
                            age = 56, 
                            dob = '', 
                            clia_number = '', 
                            patient = '', 
                            provider = '', 
                            laboratory = '', 
                            date_reported = '', 
                            date_collected = '', 
                            specimen_number = '', 
                            date_received = '', 
                            status = '', 
                            interpretation = '', ), 
                        results = [
                            haplohub.models.result_schema.ResultSchema(
                                name = '', 
                                slug = '', 
                                value = 1.337, 
                                result = '', 
                                type = '', 
                                unit = '', 
                                timestamp = '', 
                                notes = '', 
                                min_range_value = 1.337, 
                                max_range_value = 1.337, 
                                is_above_max_range = True, 
                                is_below_min_range = True, 
                                interpretation = '', 
                                loinc = '', 
                                loinc_slug = '', 
                                provider_id = '', )
                            ], )
                    ],
        )
        """

    def testResultListResponseBiomarkerResultSchema(self):
        """Test ResultListResponseBiomarkerResultSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.sample_file_api import SampleFileApi  # noqa: E501


class TestSampleFileApi(unittest.TestCase):
    """SampleFileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SampleFileApi()

    def tearDown(self) -> None:
        pass

    def test_delete_sample_file(self) -> None:
        """Test case for delete_sample_file

        Delete sample file  # noqa: E501
        """
        pass

    def test_download_link(self) -> None:
        """Test case for download_link

        Get download link  # noqa: E501
        """
        pass

    def test_finish_uploading(self) -> None:
        """Test case for finish_uploading

        Finish uploading  # noqa: E501
        """
        pass

    def test_get_sample_file(self) -> None:
        """Test case for get_sample_file

        Get sample file  # noqa: E501
        """
        pass

    def test_list_sample_files(self) -> None:
        """Test case for list_sample_files

        List sample files  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import re  # noqa: F401

from pydantic import StrictStr, validate_arguments

from haplohub.api_client import ApiClient
from haplohub.api_response import ApiResponse
from haplohub.exceptions import ApiTypeError, ApiValueError  # noqa: F401
from haplohub.models.get_prediction_response import GetPredictionResponse
from haplohub.models.get_prediction_results_response import GetPredictionResultsResponse
from haplohub.models.paginated_response_prediction_schema import PaginatedResponsePredictionSchema
from haplohub.models.run_prediction_request import RunPredictionRequest
from haplohub.models.run_prediction_response import RunPredictionResponse


class PredictionApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_prediction(self, prediction_id: StrictStr, **kwargs) -> GetPredictionResponse:  # noqa: E501
        """Get prediction  # noqa: E501

        Get prediction by its ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_prediction(prediction_id, async_req=True)
        >>> result = thread.get()

        :param prediction_id: (required)
        :type prediction_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetPredictionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_prediction_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_prediction_with_http_info(prediction_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_prediction_with_http_info(self, prediction_id: StrictStr, **kwargs) -> ApiResponse:  # noqa: E501
        """Get prediction  # noqa: E501

        Get prediction by its ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_prediction_with_http_info(prediction_id, async_req=True)
        >>> result = thread.get()

        :param prediction_id: (required)
        :type prediction_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetPredictionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["prediction_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s' to method get_prediction" % _key)
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["prediction_id"] is not None:
            _path_params["prediction_id"] = _params["prediction_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])  # noqa: E501

        # authentication setting
        _auth_settings = ["Auth0JWTBearer"]  # noqa: E501

        _response_types_map = {
            "200": "GetPredictionResponse",
        }

        return self.api_client.call_api(
            "/api/v1/prediction/{prediction_id}/",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_prediction_results(self, prediction_id: StrictStr, **kwargs) -> GetPredictionResultsResponse:  # noqa: E501
        """Get prediction results  # noqa: E501

        Get prediction results by prediction ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_prediction_results(prediction_id, async_req=True)
        >>> result = thread.get()

        :param prediction_id: (required)
        :type prediction_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetPredictionResultsResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_prediction_results_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_prediction_results_with_http_info(prediction_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_prediction_results_with_http_info(self, prediction_id: StrictStr, **kwargs) -> ApiResponse:  # noqa: E501
        """Get prediction results  # noqa: E501

        Get prediction results by prediction ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_prediction_results_with_http_info(prediction_id, async_req=True)
        >>> result = thread.get()

        :param prediction_id: (required)
        :type prediction_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetPredictionResultsResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["prediction_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s' to method get_prediction_results" % _key)
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["prediction_id"] is not None:
            _path_params["prediction_id"] = _params["prediction_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])  # noqa: E501

        # authentication setting
        _auth_settings = ["Auth0JWTBearer"]  # noqa: E501

        _response_types_map = {
            "200": "GetPredictionResultsResponse",
        }

        return self.api_client.call_api(
            "/api/v1/prediction/{prediction_id}/results/",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_predictions(self, **kwargs) -> PaginatedResponsePredictionSchema:  # noqa: E501
        """List predictions  # noqa: E501

        List all predictions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_predictions(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedResponsePredictionSchema
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_predictions_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.list_predictions_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def list_predictions_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """List predictions  # noqa: E501

        List all predictions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_predictions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedResponsePredictionSchema, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = []
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s' to method list_predictions" % _key)
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])  # noqa: E501

        # authentication setting
        _auth_settings = ["Auth0JWTBearer"]  # noqa: E501

        _response_types_map = {
            "200": "PaginatedResponsePredictionSchema",
        }

        return self.api_client.call_api(
            "/api/v1/prediction/",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def run_prediction(self, run_prediction_request: RunPredictionRequest, **kwargs) -> RunPredictionResponse:  # noqa: E501
        """Run prediction  # noqa: E501

        Run a new prediction by specified version and model ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_prediction(run_prediction_request, async_req=True)
        >>> result = thread.get()

        :param run_prediction_request: (required)
        :type run_prediction_request: RunPredictionRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunPredictionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the run_prediction_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.run_prediction_with_http_info(run_prediction_request, **kwargs)  # noqa: E501

    @validate_arguments
    def run_prediction_with_http_info(self, run_prediction_request: RunPredictionRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """Run prediction  # noqa: E501

        Run a new prediction by specified version and model ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_prediction_with_http_info(run_prediction_request, async_req=True)
        >>> result = thread.get()

        :param run_prediction_request: (required)
        :type run_prediction_request: RunPredictionRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunPredictionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["run_prediction_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s' to method run_prediction" % _key)
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["run_prediction_request"] is not None:
            _body_params = _params["run_prediction_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get("_content_type", self.api_client.select_header_content_type(["application/json"]))
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["Auth0JWTBearer"]  # noqa: E501

        _response_types_map = {
            "200": "RunPredictionResponse",
        }

        return self.api_client.call_api(
            "/api/v1/prediction/",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.metadata_api import MetadataApi  # noqa: E501


class TestMetadataApi(unittest.TestCase):
    """MetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MetadataApi()

    def tearDown(self) -> None:
        pass

    def test_accession(self) -> None:
        """Test case for accession

        Each accession is a string of DNA that is used as a reference. These are defined by https://www.ncbi.nlm.nih.gov/grc/human/data?asm=GRCh38  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional, Union

from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist


class VariantSchema(BaseModel):
    """
    VariantSchema
    """

    accession: StrictStr = Field(...)
    position: StrictInt = Field(...)
    id: Optional[StrictStr] = None
    reference: Optional[StrictStr] = None
    alternate: Optional[conlist(StrictStr)] = None
    dosage: Optional[StrictInt] = None
    is_called: StrictBool = Field(...)
    quality: Optional[Union[StrictFloat, StrictInt]] = Field(...)
    __properties = ["accession", "position", "id", "reference", "alternate", "dosage", "is_called", "quality"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VariantSchema:
        """Create an instance of VariantSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict["id"] = None

        # set to None if reference (nullable) is None
        # and __fields_set__ contains the field
        if self.reference is None and "reference" in self.__fields_set__:
            _dict["reference"] = None

        # set to None if alternate (nullable) is None
        # and __fields_set__ contains the field
        if self.alternate is None and "alternate" in self.__fields_set__:
            _dict["alternate"] = None

        # set to None if dosage (nullable) is None
        # and __fields_set__ contains the field
        if self.dosage is None and "dosage" in self.__fields_set__:
            _dict["dosage"] = None

        # set to None if quality (nullable) is None
        # and __fields_set__ contains the field
        if self.quality is None and "quality" in self.__fields_set__:
            _dict["quality"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VariantSchema:
        """Create an instance of VariantSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return VariantSchema.parse_obj(obj)

        _obj = VariantSchema.parse_obj(
            {
                "accession": obj.get("accession"),
                "position": obj.get("position"),
                "id": obj.get("id"),
                "reference": obj.get("reference"),
                "alternate": obj.get("alternate"),
                "dosage": obj.get("dosage"),
                "is_called": obj.get("is_called"),
                "quality": obj.get("quality"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.cohort_api import CohortApi  # noqa: E501


class TestCohortApi(unittest.TestCase):
    """CohortApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CohortApi()

    def tearDown(self) -> None:
        pass

    def test_create_cohort(self) -> None:
        """Test case for create_cohort

        Create cohort  # noqa: E501
        """
        pass

    def test_delete_cohort(self) -> None:
        """Test case for delete_cohort

        Delete cohort  # noqa: E501
        """
        pass

    def test_get_cohort(self) -> None:
        """Test case for get_cohort

        Get cohort  # noqa: E501
        """
        pass

    def test_list_cohorts(self) -> None:
        """Test case for list_cohorts

        List cohorts  # noqa: E501
        """
        pass

    def test_update_cohort(self) -> None:
        """Test case for update_cohort

        Update cohort  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.report_api import ReportApi  # noqa: E501


class TestReportApi(unittest.TestCase):
    """ReportApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportApi()

    def tearDown(self) -> None:
        pass

    def test_create_report(self) -> None:
        """Test case for create_report

        Create report  # noqa: E501
        """
        pass

    def test_delete_report(self) -> None:
        """Test case for delete_report

        Delete report  # noqa: E501
        """
        pass

    def test_get_report(self) -> None:
        """Test case for get_report

        Get report  # noqa: E501
        """
        pass

    def test_list_reports(self) -> None:
        """Test case for list_reports

        List reports  # noqa: E501
        """
        pass

    def test_preview_report(self) -> None:
        """Test case for preview_report

        Preview report  # noqa: E501
        """
        pass

    def test_update_report(self) -> None:
        """Test case for update_report

        Update report  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional, Union

from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr


class ResultSchema(BaseModel):
    """
    ResultSchema
    """

    name: StrictStr = Field(...)
    slug: StrictStr = Field(...)
    value: Optional[Union[StrictFloat, StrictInt]] = None
    result: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    unit: Optional[StrictStr] = None
    timestamp: Optional[datetime] = None
    notes: Optional[StrictStr] = None
    min_range_value: Optional[Union[StrictFloat, StrictInt]] = None
    max_range_value: Optional[Union[StrictFloat, StrictInt]] = None
    is_above_max_range: Optional[StrictBool] = None
    is_below_min_range: Optional[StrictBool] = None
    interpretation: Optional[StrictStr] = None
    loinc: Optional[StrictStr] = None
    loinc_slug: Optional[StrictStr] = None
    provider_id: Optional[StrictStr] = None
    __properties = [
        "name",
        "slug",
        "value",
        "result",
        "type",
        "unit",
        "timestamp",
        "notes",
        "min_range_value",
        "max_range_value",
        "is_above_max_range",
        "is_below_min_range",
        "interpretation",
        "loinc",
        "loinc_slug",
        "provider_id",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResultSchema:
        """Create an instance of ResultSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if value (nullable) is None
        # and __fields_set__ contains the field
        if self.value is None and "value" in self.__fields_set__:
            _dict["value"] = None

        # set to None if result (nullable) is None
        # and __fields_set__ contains the field
        if self.result is None and "result" in self.__fields_set__:
            _dict["result"] = None

        # set to None if type (nullable) is None
        # and __fields_set__ contains the field
        if self.type is None and "type" in self.__fields_set__:
            _dict["type"] = None

        # set to None if unit (nullable) is None
        # and __fields_set__ contains the field
        if self.unit is None and "unit" in self.__fields_set__:
            _dict["unit"] = None

        # set to None if timestamp (nullable) is None
        # and __fields_set__ contains the field
        if self.timestamp is None and "timestamp" in self.__fields_set__:
            _dict["timestamp"] = None

        # set to None if notes (nullable) is None
        # and __fields_set__ contains the field
        if self.notes is None and "notes" in self.__fields_set__:
            _dict["notes"] = None

        # set to None if min_range_value (nullable) is None
        # and __fields_set__ contains the field
        if self.min_range_value is None and "min_range_value" in self.__fields_set__:
            _dict["min_range_value"] = None

        # set to None if max_range_value (nullable) is None
        # and __fields_set__ contains the field
        if self.max_range_value is None and "max_range_value" in self.__fields_set__:
            _dict["max_range_value"] = None

        # set to None if is_above_max_range (nullable) is None
        # and __fields_set__ contains the field
        if self.is_above_max_range is None and "is_above_max_range" in self.__fields_set__:
            _dict["is_above_max_range"] = None

        # set to None if is_below_min_range (nullable) is None
        # and __fields_set__ contains the field
        if self.is_below_min_range is None and "is_below_min_range" in self.__fields_set__:
            _dict["is_below_min_range"] = None

        # set to None if interpretation (nullable) is None
        # and __fields_set__ contains the field
        if self.interpretation is None and "interpretation" in self.__fields_set__:
            _dict["interpretation"] = None

        # set to None if loinc (nullable) is None
        # and __fields_set__ contains the field
        if self.loinc is None and "loinc" in self.__fields_set__:
            _dict["loinc"] = None

        # set to None if loinc_slug (nullable) is None
        # and __fields_set__ contains the field
        if self.loinc_slug is None and "loinc_slug" in self.__fields_set__:
            _dict["loinc_slug"] = None

        # set to None if provider_id (nullable) is None
        # and __fields_set__ contains the field
        if self.provider_id is None and "provider_id" in self.__fields_set__:
            _dict["provider_id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResultSchema:
        """Create an instance of ResultSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResultSchema.parse_obj(obj)

        _obj = ResultSchema.parse_obj(
            {
                "name": obj.get("name"),
                "slug": obj.get("slug"),
                "value": obj.get("value"),
                "result": obj.get("result"),
                "type": obj.get("type"),
                "unit": obj.get("unit"),
                "timestamp": obj.get("timestamp"),
                "notes": obj.get("notes"),
                "min_range_value": obj.get("min_range_value"),
                "max_range_value": obj.get("max_range_value"),
                "is_above_max_range": obj.get("is_above_max_range"),
                "is_below_min_range": obj.get("is_below_min_range"),
                "interpretation": obj.get("interpretation"),
                "loinc": obj.get("loinc"),
                "loinc_slug": obj.get("loinc_slug"),
                "provider_id": obj.get("provider_id"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, constr

from haplohub.models.algorithm_version_schema import AlgorithmVersionSchema
from haplohub.models.id import Id


class AlgorithmSchema(BaseModel):
    """
    AlgorithmSchema
    """

    id: Id = Field(...)
    latest_version: Optional[AlgorithmVersionSchema] = None
    name: constr(strict=True, max_length=255) = Field(...)
    description: StrictStr = Field(...)
    owner: constr(strict=True, max_length=255) = Field(...)
    modified: Optional[datetime] = None
    created: Optional[datetime] = None
    __properties = ["id", "latest_version", "name", "description", "owner", "modified", "created"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AlgorithmSchema:
        """Create an instance of AlgorithmSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of id
        if self.id:
            _dict["id"] = self.id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latest_version
        if self.latest_version:
            _dict["latest_version"] = self.latest_version.to_dict()
        # set to None if latest_version (nullable) is None
        # and __fields_set__ contains the field
        if self.latest_version is None and "latest_version" in self.__fields_set__:
            _dict["latest_version"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AlgorithmSchema:
        """Create an instance of AlgorithmSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AlgorithmSchema.parse_obj(obj)

        _obj = AlgorithmSchema.parse_obj(
            {
                "id": Id.from_dict(obj.get("id")) if obj.get("id") is not None else None,
                "latest_version": AlgorithmVersionSchema.from_dict(obj.get("latest_version"))
                if obj.get("latest_version") is not None
                else None,
                "name": obj.get("name"),
                "description": obj.get("description"),
                "owner": obj.get("owner"),
                "modified": obj.get("modified"),
                "created": obj.get("created"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import json

from aenum import Enum


class PredictionStatus(str, Enum):
    """
    PredictionStatus
    """

    """
    allowed enum values
    """
    PENDING = "pending"
    RUNNING = "running"
    FAILED = "failed"
    STOPPED = "stopped"

    @classmethod
    def from_json(cls, json_str: str):
        """Create an instance of PredictionStatus from a JSON string"""
        return PredictionStatus(json.loads(json_str))



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.log_schema import LogSchema  # noqa: E501


class TestLogSchema(unittest.TestCase):
    """LogSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogSchema:
        """Test LogSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `LogSchema`
        """
        model = LogSchema()  # noqa: E501
        if include_optional:
            return LogSchema(
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                tenant = haplohub.models.tenant_schema.TenantSchema(
                    org_id = 56, 
                    org_external_id = '', ),
                auth = haplohub.models.auth_schema.AuthSchema(
                    ip = '', 
                    id = '', 
                    sub = '', ),
                request = haplohub.models.request_schema.RequestSchema(
                    method = '', 
                    path = '', 
                    env_id = 56, ),
                response = haplohub.models.response_schema.ResponseSchema(
                    status_code = 56, )
            )
        else:
            return LogSchema(
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                tenant = haplohub.models.tenant_schema.TenantSchema(
                    org_id = 56, 
                    org_external_id = '', ),
                auth = haplohub.models.auth_schema.AuthSchema(
                    ip = '', 
                    id = '', 
                    sub = '', ),
                request = haplohub.models.request_schema.RequestSchema(
                    method = '', 
                    path = '', 
                    env_id = 56, ),
                response = haplohub.models.response_schema.ResponseSchema(
                    status_code = 56, ),
        )
        """

    def testLogSchema(self):
        """Test LogSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# flake8: noqa

# import apis into api package
from haplohub.api.accession_api import AccessionApi
from haplohub.api.algorithm_api import AlgorithmApi
from haplohub.api.algorithm_result_api import AlgorithmResultApi
from haplohub.api.algorithm_version_api import AlgorithmVersionApi
from haplohub.api.api_key_api import ApiKeyApi
from haplohub.api.biomarker_api import BiomarkerApi
from haplohub.api.cohort_api import CohortApi
from haplohub.api.environment_api import EnvironmentApi
from haplohub.api.file_api import FileApi
from haplohub.api.log_api import LogApi
from haplohub.api.member_api import MemberApi
from haplohub.api.member_pgs_score_api import MemberPGSScoreApi
from haplohub.api.member_report_api import MemberReportApi
from haplohub.api.report_template_api import ReportTemplateApi
from haplohub.api.sample_api import SampleApi
from haplohub.api.trait_api import TraitApi
from haplohub.api.trait_category_api import TraitCategoryApi
from haplohub.api.upload_api import UploadApi
from haplohub.api.variant_api import VariantApi
from haplohub.api.default_api import DefaultApi



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, StrictInt, StrictStr


class ListModelsRequest(BaseModel):
    """
    ListModelsRequest
    """

    page: Optional[StrictInt] = 1
    page_size: Optional[StrictInt] = 10
    search: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    __properties = ["page", "page_size", "search", "name"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ListModelsRequest:
        """Create an instance of ListModelsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if search (nullable) is None
        # and __fields_set__ contains the field
        if self.search is None and "search" in self.__fields_set__:
            _dict["search"] = None

        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict["name"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ListModelsRequest:
        """Create an instance of ListModelsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ListModelsRequest.parse_obj(obj)

        _obj = ListModelsRequest.parse_obj(
            {
                "page": obj.get("page") if obj.get("page") is not None else 1,
                "page_size": obj.get("page_size") if obj.get("page_size") is not None else 10,
                "search": obj.get("search"),
                "name": obj.get("name"),
            }
        )
        return _obj
